# Tai Le's packages

## Reference:
From [FreeCodeCamp](https://www.freecodecamp.org/): https://www.freecodecamp.org/news/build-your-first-python-package/


## Packages available:
- PyTorch Retinaface. [Original repository](https://github.com/biubug6/Pytorch_Retinaface)
- PyTorch Arcface. [Original repository](https://github.com/deepinsight/insightface/tree/master/recognition/arcface_torch)


## Future update:
- dlib face detection
- dlib face recognition
- dlib landmark extraction


## Commands:
```
python setup.py sdist bdist_wheel
twine upload --skip-existing dist/*
```
